==> jumbo-timereport-1.0.tar.gz: jumbo-timereport-1.0/timereport/jmenu.py <==
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from admin_tools.menu import items, Menu
from jumbo.conf.admin_menu import GenericMenuItem
from jumbo.middleware.thread_local import get_current_user

def get_root_menu(children):
    user = get_current_user()
    if not user.has_perm("timereport.view_transit"):
        return None

    root_menu = items.MenuItem(
        title=_('Timereport'),
        children=[],
        url = reverse('admin:timereport_transit_changelist')
    )
    children.append(root_menu)

def add_extended_menuitems(children, current_app):
    gm = GenericMenuItem(current_app, [])
    user = get_current_user()

    add_employee = items.MenuItem(
            title=_('Add Employee'),
            children=[],
            url = reverse('admin:timereport_employee_add')
        )

    list_employee = items.MenuItem(
            title=_('List Employees'),
            children=[],
            url = reverse('admin:timereport_employee_changelist')
        )

    employee = items.MenuItem(
            title=_('Employees'),
            children=[],
            url = reverse('admin:timereport_employee_changelist')
        )
    if user.has_perm("timereport.add_employee"):
        employee.children.append(add_employee)
    if user.has_perm("timereport.view_employee"):
        employee.children.append(list_employee)
        gm.add_father(employee)

    if user.has_perm("timereport.view_transit"):
        list_transit = items.MenuItem(
            title=_('Transit calendar'),
            children=[],
            url = reverse('admin:timereport_transit_changelist')
        )
        gm.add_father(list_transit)

    if user.has_perm("timereport.can_download_report_transit"):
        download_report = items.MenuItem(
            title=_('Download report'),
            children=[],
            url = reverse('admin:timereport_transit_download')
        )
        gm.add_father(download_report)

    if user.has_perm("timereport.add_transit"):
        add_transit = items.MenuItem(
            title=_('Add transit'),
            children=[],
            url = '%s?small_view' % reverse('admin:timereport_transit_add_visual')
        )
        gm.add_father(add_transit)

    if user.has_perm("can_insert_own_manual_transit"):
        manual_transit = items.MenuItem(
            title=_('Add manual transit'),
            children=[],
            url = reverse('admin:timereport_transit_add')
        )
        gm.add_father(manual_transit)

    if user.has_perm("timereport.view_transit"):
        add_permit = items.MenuItem(
            title=_('Request permit'),
            children=[],
            url = reverse('admin:timereport_transit_add_permit')
        )
        gm.add_father(add_permit)

        add_vacation = items.MenuItem(
            title=_('Request vacation'),
            children=[],
            url = reverse('admin:timereport_transit_add_vacation')
        )
        gm.add_father(add_vacation)

        add_illness = items.MenuItem(
            title=_('Add illness'),
            children=[],
            url = reverse('admin:timereport_transit_add_illness')
        )
        gm.add_father(add_illness)

        add_injury = items.MenuItem(
            title=_('Add injury'),
            children=[],
            url = reverse('admin:timereport_transit_add_injury')
        )
        gm.add_father(add_injury)

    menu = gm.get_menu()
    [ children.append(time_menu) for time_menu in menu ]

==> jumbo-timereport-1.0.1.tar.gz: jumbo-timereport-1.0.1/timereport/jmenu.py <==
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from admin_tools.menu import items, Menu
from jumbo.conf.admin_menu import GenericMenuItem
from jumbo.middleware.thread_local import get_current_user

def get_root_menu(children):
    user = get_current_user()
    if not user.has_perm("timereport.view_transit"):
        return None

    root_menu = items.MenuItem(
        title=_('Timereport'),
        children=[],
        url = reverse('admin:timereport_transit_changelist')
    )
    children.append(root_menu)

def add_extended_menuitems(children, current_app):
    gm = GenericMenuItem(current_app, [])
    user = get_current_user()

    add_employee = items.MenuItem(
            title=_('Add Employee'),
            children=[],
            url = reverse('admin:timereport_employee_add')
        )

    list_employee = items.MenuItem(
            title=_('List Employees'),
            children=[],
            url = reverse('admin:timereport_employee_changelist')
        )

    employee = items.MenuItem(
            title=_('Employees'),
            children=[],
            url = reverse('admin:timereport_employee_changelist')
        )
    if user.has_perm("timereport.add_employee"):
        employee.children.append(add_employee)
    if user.has_perm("timereport.view_employee"):
        employee.children.append(list_employee)
        gm.add_father(employee)

    if user.has_perm("timereport.view_transit"):
        list_transit = items.MenuItem(
            title=_('Transit calendar'),
            children=[],
            url = reverse('admin:timereport_transit_changelist')
        )
        gm.add_father(list_transit)

    if user.has_perm("timereport.can_download_report_transit"):
        download_report = items.MenuItem(
            title=_('Download report'),
            children=[],
            url = reverse('admin:timereport_transit_download')
        )
        gm.add_father(download_report)

    if user.has_perm("timereport.add_transit"):
        add_transit = items.MenuItem(
            title=_('Add transit'),
            children=[],
            url = '%s?small_view' % reverse('admin:timereport_transit_add_visual')
        )
        gm.add_father(add_transit)

    if user.has_perm("can_insert_own_manual_transit"):
        manual_transit = items.MenuItem(
            title=_('Add manual transit'),
            children=[],
            url = reverse('admin:timereport_transit_add')
        )
        gm.add_father(manual_transit)

    if user.has_perm("timereport.view_transit"):
        # add_permit = items.MenuItem(
        #     title=_('Request permit'),
        #     children=[],
        #     url = reverse('admin:timereport_transit_add_permit')
        # )
        # gm.add_father(add_permit)

        add_vacation = items.MenuItem(
            title=_('Request'),
            children=[],
            url = reverse('admin:timereport_period_add_vacation')
        )
        gm.add_father(add_vacation)


    menu = gm.get_menu()
    [ children.append(time_menu) for time_menu in menu ]
